##  Accessing the Survey Response Form
All surveys that need your response are found in the Collaboration tab in a centralized location for easy access and management. This centralized location ensures that survey responses are organized and readily available.
To access a survey, do the following:
  1. Navigate to the Collaboration tab.
  2. In the left side pane, under Surveys, select Assigned to Me.
  3. Open the survey from the list by clicking on the survey title.


![Accessing the Survey in the Collaboration Tab](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275046457a4410149d5ece00a8d69ea2_LowRes.png)
Accessing the Survey in the Collaboration Tab
Alternatively, recipients can access the survey directly through the Surveys tab of the relevant fact sheet. Click Edit against the survey you want to answer, and it opens the respective survey response form.
![Accessing the Survey in the Fact Sheet](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274f454f7a441014a2188672b8024379_LowRes.png)
Accessing the Survey in the Fact Sheet
When you are the recipient of a new survey, you receive an email notification asking you to participate in the survey. In the email, click Go to Survey to open the survey response form.
![Email Invite for Survey Participation](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275352a77a441014a876bb6d3a778664_LowRes.png)
Email Invite for Survey Participation
